/*
 * SiteList.java
 *
 * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
 *
 * This file is part of BEAST.
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership and licensing.
 *
 * BEAST is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 *  BEAST is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with BEAST; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */

package dr.evolution.alignment;

/**
 * interface for any list of sites.
 *
 * @version $Id: SiteList.java,v 1.9 2005/05/24 20:25:55 rambaut Exp $
 *
 * @author Andrew Rambaut
 */
public interface SiteList extends PatternList {
	/**
	 * @return number of sites
	 */
	int getSiteCount();

	/** 
	 * Gets the pattern of site as an array of state numbers (one per sequence) 
	 * @return the site pattern at siteIndex
	 */
	int[] getSitePattern(int siteIndex);

	/**
	 * Gets the pattern of site as an array of state frequency vectors (one per sequence)
	 * @return the site pattern at siteIndex
	 */
	double[][] getUncertainSitePattern(int siteIndex);

	/**
	 * Gets the pattern index at a particular site
	 * @return the patternIndex
	 */
	int getPatternIndex(int siteIndex);
	
	/** 
	 * @return the sequence state at (taxon, site) 
	 */
	int getState(int taxonIndex, int siteIndex);

	/**
	 * @return the sequence state frequency vector at (taxon, site)
	 */
	double[] getUncertainState(int taxonIndex, int siteIndex);
}
